@@ -1,14 +1,14 @@
-#helper
+# helper
 #' @export
-'[.xRingList' <-
+"[.xRingList" <-
   function(x, i, ...) {
     r <- NextMethod("[")
     class(r) <- class(x)
     r
   }
 
-as.xRingList = function(x) {
+as.xRingList <- function(x) {
   x <- lapply(x, as.xRing)
   class(x) <- c("xRingList", "list")
-  return(x)
+  x
 }
