@@ -6,13 +6,13 @@
 #' @return an object of class "xRingList" with merged fragments
 #' @export
 #' @examples
-#' 
-#'  data(PaPiRaw)
-#'  data(PaPiSpan)
-#'  PaPi <- detectRings(PaPiRaw, PaPiSpan)
-#'  PaPi.merge <- combineFrag(PaPi, frag = 9)
-#' 
-combineFrag = function(x, frag = NULL) {
+#'
+#' data(PaPiRaw)
+#' data(PaPiSpan)
+#' PaPi <- detectRings(PaPiRaw, PaPiSpan)
+#' PaPi.merge <- combineFrag(PaPi, frag = 9)
+#'
+combineFrag <- function(x, frag = NULL) {
   if (!(c("xRingList") %in% class(x))) {
     stop("Use only with \"xRingList\" objects.")
   }
@@ -23,8 +23,9 @@ combineFrag = function(x, frag = NULL) {
     message("Series without fragments")
     return(x)
   }
-  if (is.null(frag))
+  if (is.null(frag)) {
     frag <- nNameLength[length(nNameLength) - 1] + 1
+  }
 
   coresNames <- substr(seriesName, 1, frag - 1)
   uniqueSeries <- unique(coresNames)
@@ -35,5 +36,5 @@ combineFrag = function(x, frag = NULL) {
     out[i] <- putTogether(x[coresNames %in% i], newName = i)
   }
   class(out) <- c("xRingList", "list")
-  return(out)
+  out
 }
