@@ -1,3 +1,3 @@
-findValleys = function(x) {
+findValleys <- function(x) {
   which(diff(sign(diff(x, na.pad = FALSE)), na.pad = FALSE) > 0) + 1
 }
