@@ -1,4 +1,4 @@
-removeRingSeries = function(xray, x) {
+removeRingSeries <- function(xray, x) {
   for (i in 1:length(x)) {
     xLimite <- abs(xray$limits - x[i])
     year <-
@@ -8,8 +8,8 @@ removeRingSeries = function(xray, x) {
       limits <- xray$limits[-which(xray$years == year)]
     xray$years <- years <- xray$years[-1]
     xray$trw <- as.data.frame(matrix(diff(limits),
-                                     dimnames = list(years[-1], xray$names)))
+      dimnames = list(years[-1], xray$names)
+    ))
   }
   xray
 }
-
