@@ -1,12 +1,11 @@
 
-rollMax =  function(x, k, align = c("center", "left", "right"), fill=NA) {
+rollMax <- function(x, k, align = c("center", "left", "right"), fill = NA) {
   n_s <- length(x) - k + 1
   out <- rep(NA, n_s)
-  for (i in seq(1, n_s )) { # seq_len
+  for (i in seq(1, n_s)) { # seq_len
     out[i] <- max(x[i + 0:(k - 1)])
   }
-  out <- switch(
-    match.arg(align),
+  out <- switch(match.arg(align),
     "left" = {
       c(out, rep(fill, k - 1))
     },
@@ -17,6 +16,5 @@ rollMax =  function(x, k, align = c("center", "left", "right"), fill=NA) {
       c(rep(fill, k - 1), out)
     }
   )
-  return(out)
+  out
 }
-
